using MongoDB.Driver;
using Robware.Auth.API;
using Robware.Data.ApiKeys;
using Robware.Data.ApiKeys.State;
using System;
using System.Threading.Tasks;

namespace Robware.Data {
	public class ApiKeyRepository : IApiKeys {
		private readonly IMongoCollection<ApiKeyState> _collection;

		public ApiKeyRepository(IMongoDatabase database) {
			_collection = database.GetCollection<ApiKeyState>("api-keys");
		}
		
		public async Task<ApiKey> Get(string apiKey) {
			var result = (await _collection.FindAsync(key => key.Key == apiKey)).FirstOrDefault();

			if (result == null)
				throw new ApiKeyNotFoundException(apiKey);

			return new DatabaseApiKey(result);
		}

		public async Task<ApiKey> Create(string name) {
			var apiKey = new ApiKey {
				Name = name,
				Key = Guid.NewGuid().ToString(),
				Enabled = true,
				IssueTimestamp = DateTime.Now
			};

			await _collection.InsertOneAsync(new ApiKeyState(apiKey));

			return apiKey;
		}
	}
}